/*  ___   ___  ___  _   _  ___   ___   ____ ___  ____  
 * / _ \ /___)/ _ \| | | |/ _ \ / _ \ / ___) _ \|    \ 
 *| |_| |___ | |_| | |_| | |_| | |_| ( (__| |_| | | | |
 * \___/(___/ \___/ \__  |\___/ \___(_)____)___/|_|_|_|
 *                  (____/ 
 * OSOYOO IoT Tutorial: Use OSOYOO IoT APP to turn on/off BUZZER on NodeMCU 
 * You can also adjust the sound level with the top slider
 * Hardware: OSOYOO NodeMCU board, BUZZER, 200 ohm resistor, breadboard
 * Tutorial link: https://osoyoo.com/?p=52696
 * CopyRIGHT www.osoyoo.com
*/


#include <ESP8266WiFi.h>
#include <WiFiUdp.h>

const char* ssid = "replace_with_your_SSID_here";
const char* password = "replace_with_your_password_here";
const int BUZZER = D2;
const int localPort = 8888;

WiFiUDP udp;
char packetBuffer[UDP_TX_PACKET_MAX_SIZE + 1];

void setup() {
  pinMode(BUZZER, OUTPUT);
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    Serial.println('.');
    delay(500);
  }
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
  Serial.printf("UDP server on port %d\n", localPort);
  udp.begin(localPort);
}

void loop() {
  int packetSize = udp.parsePacket();
  if (packetSize) {
    Serial.printf("Received packet of size %d from %s:%d\n",
                  packetSize,
                  udp.remoteIP().toString().c_str(), udp.remotePort());
    int n = udp.read(packetBuffer, UDP_TX_PACKET_MAX_SIZE);
    packetBuffer[n] = 0;
    Serial.println("Contents:");
    Serial.println(packetBuffer);
        if (packetBuffer[0]=='F') {
    digitalWrite(BUZZER,HIGH);
    Serial.println("Buzzer on!");

    }
    else if (packetBuffer[0]=='G') {
      digitalWrite(BUZZER,LOW);
      Serial.println("Buzzer off!");

    }
    else if (packetBuffer[0]=='S') 
    {
       if(packetBuffer[1] == 'T')
        {
            int sound = get_value(packetBuffer);
            sound = map(sound, 0, 100,  0,255);
            Serial.print("Buzzer sound value is:");
            Serial.println(sound);
            analogWrite(BUZZER, sound);               
         }   
    }
  }
}
int get_value(char bf[])
{
  int value = bf[3]- '0';
  
  for(int i = 4; i < 6; i++)
  {
    if(bf[i] < '0' || bf[i] > '9')
      break;
    else
      value = value * 10 + bf[i] - '0';
  }
  
  return value;
}

